==> xwiki-rendering-macro-html-3.0-sources.jar: org/xwiki/rendering/internal/macro/html/HTMLMacroXHTMLRendererFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.macro.html;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.internal.renderer.AbstractPrintRendererFactory;
import org.xwiki.rendering.syntax.Syntax;
import org.xwiki.rendering.syntax.SyntaxType;

/**
 * Create XHTML Renderers for the HTML Macro, see {@link HTMLMacroXHTMLRenderer}.
 *
 * @version $Id: HTMLMacroXHTMLRendererFactory.java 22735 2009-08-14 07:34:43Z vmassol $
 * @since 2.0M3
 */
@Component("xhtmlmacro/1.0")
public class HTMLMacroXHTMLRendererFactory extends AbstractPrintRendererFactory
{
    /**
     * The special syntax to recognize the HTML Macro XHTML Renderer.
     */
    private static final Syntax SYNTAX = new Syntax(new SyntaxType("xhtmlmacro", "XHTML Macro"), "1.0");

    /**
     * {@inheritDoc}
     * @see AbstractPrintRendererFactory#getSyntax()
     */
    public Syntax getSyntax()
    {
        return SYNTAX;
    }
}

==> xwiki-rendering-macro-html-4.1-sources.jar: org/xwiki/rendering/internal/macro/html/HTMLMacroXHTMLRendererFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.macro.html;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.internal.renderer.AbstractPrintRendererFactory;
import org.xwiki.rendering.syntax.Syntax;
import org.xwiki.rendering.syntax.SyntaxType;

/**
 * Create XHTML Renderers for the HTML Macro, see {@link HTMLMacroXHTMLRenderer}.
 *
 * @version $Id$
 * @since 2.0M3
 */
@Component
@Named("xhtmlmacro/1.0")
@Singleton
public class HTMLMacroXHTMLRendererFactory extends AbstractPrintRendererFactory
{
    /**
     * The special syntax to recognize the HTML Macro XHTML Renderer.
     */
    private static final Syntax SYNTAX = new Syntax(new SyntaxType("xhtmlmacro", "XHTML Macro"), "1.0");

    @Override
    public Syntax getSyntax()
    {
        return SYNTAX;
    }
}
